@@ -20,7 +20,6 @@
 #include <sys/stat.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include <glib/gstdio.h>
 #include <libgnomecanvas/libgnomecanvas.h>
 
 #include "xournal.h"
@@ -58,7 +57,7 @@ void init_stuff (int argc, char *argv[])
 
   // initialize config file names
   tmppath = g_build_filename(g_get_home_dir(), CONFIG_DIR, NULL);
-  g_mkdir(tmppath, 0700); // safer (MRU data may be confidential)
+  mkdir(tmppath, 0700); // safer (MRU data may be confidential)
   ui.mrufile = g_build_filename(tmppath, MRU_FILE, NULL);
   ui.configfile = g_build_filename(tmppath, CONFIG_FILE, NULL);
   g_free(tmppath);
@@ -99,7 +98,6 @@ void init_stuff (int argc, char *argv[])
 
   ui.selection = NULL;
   ui.cursor = NULL;
-  ui.pen_cursor_pix = ui.hiliter_cursor_pix = NULL;
 
   ui.cur_brush = &(ui.brushes[0][ui.toolno[0]]);
   for (j=0; j<=NUM_BUTTONS; j++)
@@ -119,8 +117,6 @@ void init_stuff (int argc, char *argv[])
 
   ui.cur_mapping = 0;
   ui.which_unswitch_button = 0;
-  ui.in_proximity = FALSE;
-  ui.warned_generate_fontconfig = FALSE;
   
   reset_recognizer();
 
@@ -133,8 +129,6 @@ void init_stuff (int argc, char *argv[])
 
   gtk_check_menu_item_set_active(
     GTK_CHECK_MENU_ITEM(GET_COMPONENT("journalApplyAllPages")), ui.bg_apply_all_pages);
-  gtk_check_menu_item_set_active(
-    GTK_CHECK_MENU_ITEM(GET_COMPONENT("journalNewPageKeepsBG")), ui.new_page_bg_from_pdf);
   if (ui.fullscreen) {
     gtk_check_menu_item_set_active(
       GTK_CHECK_MENU_ITEM(GET_COMPONENT("viewFullscreen")), TRUE);
@@ -165,11 +159,7 @@ void init_stuff (int argc, char *argv[])
   w = GET_COMPONENT("scrolledwindowMain");
   gtk_container_add (GTK_CONTAINER (w), GTK_WIDGET (canvas));
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW (w), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  gtk_widget_set_events (GTK_WIDGET (canvas), 
-     GDK_EXPOSURE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_MOTION_MASK | 
-     GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_KEY_PRESS_MASK | 
-     GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK |
-     GDK_PROXIMITY_IN_MASK | GDK_PROXIMITY_OUT_MASK);
+  gtk_widget_set_events (GTK_WIDGET (canvas), GDK_EXPOSURE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_MOTION_MASK | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_KEY_PRESS_MASK | GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
   gnome_canvas_set_pixels_per_unit (canvas, ui.zoom);
   gnome_canvas_set_center_scroll_region (canvas, TRUE);
   gtk_layout_get_hadjustment(GTK_LAYOUT (canvas))->step_increment = ui.scrollbar_step_increment;
@@ -190,12 +180,6 @@ void init_stuff (int argc, char *argv[])
   g_signal_connect ((gpointer) canvas, "leave_notify_event",
                     G_CALLBACK (on_canvas_leave_notify_event),
                     NULL);
-  g_signal_connect ((gpointer) canvas, "proximity_in_event",
-                    G_CALLBACK (on_canvas_proximity_event),
-                    NULL);
-  g_signal_connect ((gpointer) canvas, "proximity_out_event",
-                    G_CALLBACK (on_canvas_proximity_event),
-                    NULL);
   g_signal_connect ((gpointer) canvas, "expose_event",
                     G_CALLBACK (on_canvas_expose_event),
                     NULL);
@@ -208,9 +192,6 @@ void init_stuff (int argc, char *argv[])
   g_signal_connect ((gpointer) gtk_layout_get_vadjustment(GTK_LAYOUT(canvas)),
                     "value-changed", G_CALLBACK (on_vscroll_changed),
                     NULL);
-  g_signal_connect ((gpointer) gtk_layout_get_hadjustment(GTK_LAYOUT(canvas)),
-                    "value-changed", G_CALLBACK (on_hscroll_changed),
-                    NULL);
   g_object_set_data (G_OBJECT (winMain), "canvas", canvas);
 
   screen = gtk_widget_get_screen(winMain);
@@ -243,14 +224,8 @@ void init_stuff (int argc, char *argv[])
     GTK_CHECK_MENU_ITEM(GET_COMPONENT("optionsProgressiveBG")), ui.progressive_bg);
   gtk_check_menu_item_set_active(
     GTK_CHECK_MENU_ITEM(GET_COMPONENT("optionsPrintRuling")), ui.print_ruling);
-  gtk_check_menu_item_set_active(
-    GTK_CHECK_MENU_ITEM(GET_COMPONENT("optionsLegacyPDFExport")), ui.exportpdf_prefer_legacy);
-  gtk_check_menu_item_set_active(
-    GTK_CHECK_MENU_ITEM(GET_COMPONENT("optionsLayersPDFExport")), ui.exportpdf_layers);
   gtk_check_menu_item_set_active(
     GTK_CHECK_MENU_ITEM(GET_COMPONENT("optionsAutoloadPdfXoj")), ui.autoload_pdf_xoj);
-  gtk_check_menu_item_set_active(
-    GTK_CHECK_MENU_ITEM(GET_COMPONENT("optionsAutosaveXoj")), ui.autosave_enabled);
   gtk_check_menu_item_set_active(
     GTK_CHECK_MENU_ITEM(GET_COMPONENT("optionsLeftHanded")), ui.left_handed);
   gtk_check_menu_item_set_active(
@@ -259,8 +234,6 @@ void init_stuff (int argc, char *argv[])
     GTK_CHECK_MENU_ITEM(GET_COMPONENT("optionsAutoSavePrefs")), ui.auto_save_prefs);
   gtk_check_menu_item_set_active(
     GTK_CHECK_MENU_ITEM(GET_COMPONENT("optionsButtonSwitchMapping")), ui.button_switch_mapping);
-  gtk_check_menu_item_set_active(
-    GTK_CHECK_MENU_ITEM(GET_COMPONENT("optionsPenCursor")), ui.pen_cursor);
   
   hide_unimplemented();
 
@@ -331,7 +304,7 @@ void init_stuff (int argc, char *argv[])
   if (!success) {
     w = gtk_message_dialog_new(GTK_WINDOW (winMain), GTK_DIALOG_DESTROY_WITH_PARENT,
        GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Error opening file '%s'"), argv[1]);
-    wrapper_gtk_dialog_run(GTK_DIALOG(w));
+    gtk_dialog_run(GTK_DIALOG(w));
     gtk_widget_destroy(w);
   }
 }
@@ -351,16 +324,16 @@ main (int argc, char *argv[])
   gtk_set_locale ();
   gtk_init (&argc, &argv);
 
+  add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE "/pixmaps");
   path = g_path_get_dirname(argv[0]);
   path1 = g_build_filename(path, "pixmaps", NULL);
   path2 = g_build_filename(path, "..", "pixmaps", NULL);
-  add_pixmap_directory (path);
-  add_pixmap_directory (path2);
   add_pixmap_directory (path1);
+  add_pixmap_directory (path2);
+  add_pixmap_directory (path);
   g_free(path);
   g_free(path1);
   g_free(path2);
-  add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE "/pixmaps");
 
   /*
    * The following code was added by Glade to create one of each component
@@ -377,7 +350,6 @@ main (int argc, char *argv[])
   if (bgpdf.status != STATUS_NOT_INIT) shutdown_bgpdf();
 
   save_mru_list();
-  autosave_cleanup(&ui.autosave_filename_list);
   if (ui.auto_save_prefs) save_config_to_file();
   
   return 0;
