@@ -27,7 +27,6 @@
 #include "xo-misc.h"
 #include "xo-paint.h"
 #include "xo-image.h"
-#include "xo-selection.h"
 
 // the various formats in which we might present clipboard data
 #define TARGET_XOURNAL 1
@@ -72,7 +71,7 @@ void callback_clipboard_clear(GtkClipboard *clipboard, gpointer user_data)
   
   if (sel->xo_data!=NULL) g_free(sel->xo_data);
   if (sel->text_data!=NULL) g_free(sel->text_data);
-  if (sel->image_data!=NULL) g_object_unref(sel->image_data);
+  if (sel->image_data!=NULL) gdk_pixbuf_unref(sel->image_data);
   g_free(sel);
 }
 
@@ -335,7 +334,7 @@ void clipboard_paste_text(gchar *text)
   ui.cur_layer->items = g_list_append(ui.cur_layer->items, item);
   ui.cur_layer->nitems++;
   item->type = ITEM_TEXT;
-  g_memmove(&(item->brush), &(ui.brushes[ui.cur_mapping][TOOL_PEN]), sizeof(struct Brush));
+  g_memmove(&(item->brush), ui.cur_brush, sizeof(struct Brush));
   item->text = text; // text was newly allocated, we keep it
   item->font_name = g_strdup(ui.font_name);
   item->font_size = ui.font_size;
@@ -402,9 +401,6 @@ void clipboard_paste(void)
   sel_data = gtk_clipboard_wait_for_contents(
       clipboard,
       gdk_atom_intern(XOURNAL_TARGET_ATOM, FALSE));
-  // avoid a bug (mostly win32, also xclip?) presenting images as xournal data
-  if (gtk_selection_data_get_data_type(sel_data)!=gdk_atom_intern(XOURNAL_TARGET_ATOM, FALSE))
-    { gtk_selection_data_free(sel_data); sel_data = NULL; }
   ui.cur_item_type = ITEM_NONE;
   if (sel_data != NULL) { 
     clipboard_paste_from_xournal(sel_data);
