@@ -13,9 +13,6 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-gchar *xo_basename(gchar *s, gboolean xplatform);
-gchar *candidate_save_filename(void);
-
 // data manipulation misc functions
 
 struct Page *new_page(struct Page *template);
@@ -43,7 +40,6 @@ void get_pointer_coords(GdkEvent *event, double *ret);
 void get_current_pointer_coords(double *ret);
 double get_pressure_multiplier(GdkEvent *event);
 void fix_xinput_coords(GdkEvent *event);
-void emergency_enable_xinput(GdkInputMode mode);
 void update_item_bbox(struct Item *item);
 void make_page_clipbox(struct Page *pg);
 void make_canvas_items(void);
@@ -138,9 +134,6 @@ wrapper_poppler_page_render_to_pixbuf (PopplerPage *page,
 			       int rotation,
 			       GdkPixbuf *pixbuf);
 
-// wrapper for gtk_dialog_run that disables xinput (bug #159)
-gint wrapper_gtk_dialog_run(GtkDialog *dialog);
-
 // defines for paper rulings
 
 #define RULING_MARGIN_COLOR 0xff0080ff
