@@ -21,8 +21,6 @@ void update_cursor_for_resize(double *pt);
 void create_new_stroke(GdkEvent *event);
 void continue_stroke(GdkEvent *event);
 void finalize_stroke(void);
-void abort_stroke(void);
-void subdivide_cur_path(void);
 
 void do_eraser(GdkEvent *event, double radius, gboolean whole_strokes);
 void finalize_erasure(void);
@@ -31,11 +29,7 @@ void do_hand(GdkEvent *event);
 
 /* text functions */
 
-#ifdef WIN32
-#define DEFAULT_FONT "Arial"
-#else
 #define DEFAULT_FONT "Sans"
-#endif
 #define DEFAULT_FONT_SIZE 12
 
 void start_text(GdkEvent *event, struct Item *item);
